@@ -23,7 +23,7 @@ sed -i -e "s#\$HOME#$HOME#g" cron/{{ jobName }}
 sed -i -e "s#\$PWD#$PWD#g" cron/{{ jobName }}
 chmod +x cron/{{ jobName }}
 
-if (( $(crontab -l | grep -c "cron_{{ jobName }}" ) == 0 )) ; then
+if (( $(crontab -l | grep -c "{{ hchk }}" ) == 0 )) ; then
     crontab -l > _cron
     if (( $(crontab -l | grep -c "APP_NAME=" ) == 0 )) ; then
         env >> _cron
