@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12484 2020-08-27 09:08:55Z Lavender $
+# $Id: __init__.py 12506 2020-09-04 05:40:25Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-08-27 18:08:55 +0900 (週四, 27 八月 2020) $
-# $Revision: 12484 $
+# $Date: 2020-09-04 14:40:25 +0900 (週五, 04 九月 2020) $
+# $Revision: 12506 $
 
 import os
 import re
@@ -31,7 +31,8 @@ from collections import OrderedDict
 
 import twder
 
-from oscar.templatetags.currency_filters import currency
+from babel.numbers import format_currency
+from django.utils.translation import get_language, to_locale
 
 from Iuppiter.Encoding import utf8
 from Iuppiter.Encryption import Encryptor
@@ -959,8 +960,11 @@ def buildAPIForm(submission, request, apiName, extra={}):
 
         itemName = utf8(itemName)
         
-        currencyStr = currency(total, submission['order_total'].currency).replace(",", "")
-        total = int(re.findall(r"[0-9\.]+", currencyStr)[0])
+        currencyStr = format_currency(
+            total, currency=submission['order_total'].currency, format='##0', currency_digits=False,
+            locale=to_locale(get_language() or settings.LANGUAGE_CODE))
+        
+        total = int(currencyStr)
         
     # merchantTradeNo
     basketId = basket.id
