@@ -41,15 +41,24 @@ from Iuno import attachSettings, DEVELOPMENT
 
 logger = createLogger(__name__)
 
-def importSettings(settingsDict, settings):
+TEST_DB = 'db_test.sqlite'
+
+def importSettings(settingsDict, settings):  
     settingsDict.update({k: getattr(settings, k) for k in dir(settings)})
     testSettings = {
         "SERVER_MODE": DEVELOPMENT,
         "DEBUG": True,
+        "DATABASES": {
+            'default': {
+                'ENGINE': 'django.db.backends.sqlite3',
+                'NAME': TEST_DB,
+            }
+        },
+        "SITE_ID": 1,
     }
-    update(settingsDict, testSettings)
     attachSettings(settingsDict)
-    
+    settingsDict.update(testSettings)
+   
 CHROME_VERSION_PATH = os.path.join("chromedriver.txt")
 
 def downloadChromedriver():
@@ -312,16 +321,22 @@ class SeleniumMixin(object):
     def _runServer(cls):
         env = os.environ.copy()
         envPython = sys.executable
+        
+        if os.path.exists(TEST_DB):
+            os.remove(TEST_DB)
+        
+        os.system('"%s" manage.py migrate --settings %s' % (envPython, cls.TEST_SETTINGS))
+        os.system('"%s" manage.py loaddata %s --settings %s' % (envPython, cls.INITIAL_DATA, cls.TEST_SETTINGS))
        
         if cls.TEST_SETTINGS:
             p = subprocess.Popen(
-                ('"%s" manage.py testserver %s --addrport %s --settings %s') % (
-                    envPython, cls.INITIAL_DATA, cls.PORT, cls.TEST_SETTINGS), 
+                ('"%s" manage.py runserver %s --noreload --settings %s') % (
+                    envPython, cls.PORT, cls.TEST_SETTINGS), 
                 env=env, shell=True, cwd=".")
         else:
             p = subprocess.Popen(
-                ('"%s" manage.py testserver %s --addrport %s') % (
-                    envPython, cls.INITIAL_DATA, cls.PORT), 
+                ('"%s" manage.py runserver %s --noreload') % (
+                    envPython, cls.PORT), 
                 env=env, shell=True, cwd=".")
        
         time.sleep(20)
